import re

def owoize(string):
    #Note that order is important in these as they are executed in order
    patterns = {
        r"\?$" : "Ouuh~wOuuh~♪",
        r"\?" : "?~~~",
        r"l" : "w",
        r"please" : "pws",
        r"Please" : "~Pws",
        r"r" : "w",
        r"\!" : "^w^",
        r"ary" : "aryweary"
        }

    for key in patterns:
        regex = re.compile(key)
        string = re.sub(key, patterns[key], string)

    return string


from distutils.core import setup
setup(
  name = 'uwuizer',
  packages = ['uwuizer'],
  version = '1.0.2',
  license='MIT',
  description = 'uwu text generator ٩(◕‿◕｡)۶',
  author = 'Philip Jones',
  author_email = 'philipjonesma@gmail.com',
  url = 'https://github.com/Philinphiladelphia/uwu',
  download_url = 'https://github.com/Philinphiladelphia/uwu/archive/refs/tags/v_1.0.0.tar.gz',
  keywords = ['uwu', "( ‾́ ◡ ‾́ )"], 
  install_requires=[
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)